@@ -1,5 +1,5 @@
 from finvizfinance.group.overview import Overview
-from finvizfinance.util import webScrap, imageScrap
+from finvizfinance.util import web_scrap, image_scrap
 
 """
 .. module:: group.spectrum
@@ -13,14 +13,14 @@ class Spectrum(Overview):
     """Spectrum inherit from overview module.
     Getting information from the finviz group spectrum page.
     """
-    def __init__(self):
-        """initiate module
-        """
-        self.BASE_URL = 'https://finviz.com/groups.ashx?{group}&v=310'
-        self.url = self.BASE_URL.format(group='g=sector')
-        Overview._loadSetting(self)
 
-    def ScreenerView(self, group='Sector', order='Name', out_dir=''):
+    def __init__(self):
+        """initiate module"""
+        self.BASE_URL = "https://finviz.com/groups.ashx?{group}&v=310"
+        self.url = self.BASE_URL.format(group="g=sector")
+        Overview._load_setting(self)
+
+    def screener_view(self, group="Sector", order="Name", out_dir=""):
         """Get screener table.
 
         Args:
@@ -31,8 +31,12 @@ class Spectrum(Overview):
             raise ValueError()
         if order not in self.order_dict:
             raise ValueError()
-        self.url = self.BASE_URL.format(group=self.group_dict[group])+'&'+self.order_dict[order]
+        self.url = (
+            self.BASE_URL.format(group=self.group_dict[group])
+            + "&"
+            + self.order_dict[order]
+        )
 
-        soup = webScrap(self.url)
-        url = 'https://finviz.com/' + soup.findAll('img')[5]['src']
-        imageScrap(url, group, '')
\ No newline at end of file
+        soup = web_scrap(self.url)
+        url = "https://finviz.com/" + soup.findAll("img")[5]["src"]
+        image_scrap(url, group, "")
