@@ -1,5 +1,6 @@
-from finvizfinance.util import webScrap
 import pandas as pd
+from finvizfinance.util import web_scrap
+
 """
 .. module:: news
    :synopsis: news table.
@@ -7,7 +8,7 @@ import pandas as pd
 .. moduleauthor:: Tianning Li <ltianningli@gmail.com>
 """
 
-NEWS_URL = 'https://finviz.com/news.ashx'
+NEWS_URL = "https://finviz.com/news.ashx"
 
 
 class News:
@@ -15,14 +16,14 @@ class News:
     Getting information from the finviz news page.
 
     """
+
     def __init__(self):
-        """initiate module
-        """
+        """initiate module"""
         self.all_news = {}
-        self.soup = webScrap(NEWS_URL)
+        self.soup = web_scrap(NEWS_URL)
         self.news = {}
 
-    def getNews(self):
+    def get_news(self):
         """Get insider information table.
 
         Retrieves table information from finviz finance news.
@@ -31,15 +32,15 @@ class News:
             news(dict): news table
 
         """
-        tables = self.soup.findAll('table')
+        tables = self.soup.findAll("table")
         news = tables[6]
-        news_df = self._getNewsHelper(news)
+        news_df = self._get_news_helper(news)
         blog = tables[7]
-        blog_df = self._getNewsHelper(blog)
-        self.news = {'news': news_df, 'blogs': blog_df}
+        blog_df = self._get_news_helper(blog)
+        self.news = {"news": news_df, "blogs": blog_df}
         return self.news
 
-    def _getNewsHelper(self, rows):
+    def _get_news_helper(self, rows):
         """Get insider information table helper function.
 
         Args:
@@ -49,16 +50,18 @@ class News:
             df(pandas.DataFrame): news information table
 
         """
-        df = pd.DataFrame([], columns=['Date', 'Title', 'Source', 'Link'])
-        rows = rows.findAll('tr')
+        df = pd.DataFrame([], columns=["Date", "Title", "Source", "Link"])
+        rows = rows.findAll("tr")
         for row in rows:
-            cols = row.findAll('td')
+            cols = row.findAll("td")
             date = cols[1].text
             title = cols[2].text
-            link = cols[2].a['href']
-            source = link.split('/')[2]
-            if source == 'feedproxy.google.com':
-                source = link.split('/')[4]
-            df = df.append({'Date': date, 'Title': title, 'Source': source, 'Link': link},
-                           ignore_index=True)
-        return df
\ No newline at end of file
+            link = cols[2].a["href"]
+            source = link.split("/")[2]
+            if source == "feedproxy.google.com":
+                source = link.split("/")[4]
+            df = df.append(
+                {"Date": date, "Title": title, "Source": source, "Link": link},
+                ignore_index=True,
+            )
+        return df
